@@ -8,6 +8,8 @@ class Plot:
 		buffer = StringIO.StringIO()
 		if type(plt_obj).__name__ == 'Figure':
 			plt_obj.savefig(buffer,format='png',bbox_inches='tight')
+		else:
+			print("Error: getPlot method must return an pyplot figure object")
 		plt.close('all')
 		return(buffer)
 
@@ -15,4 +17,8 @@ class Image:
 	def getImagePath(self, img_obj):
 		buffer = StringIO.StringIO()
 		mpimg.imsave(buffer,img_obj)
+		try:
+			mpimg.imsave(buffer,img_obj)
+		except:
+			print("Error: getImage method must return an image object")
 		return(buffer)
