@@ -7,8 +7,10 @@ import pandas as pd
 import numpy as np
 
 import model
-import View
-import spyre
+try:
+	import View
+except:
+	import view as View
 
 import cherrypy
 from cherrypy.lib.static import serve_file
@@ -119,7 +121,6 @@ class Root(object):
 	def download(self, **args):
 		args = self.clean_args(args)
 		filepath = self.getDownload(args)
-		print type(filepath).__name__
 		if type(filepath).__name__=="str":
 			return serve_file(filepath, "application/x-download", "attachment", name='data.csv')
 		if type(filepath).__name__=="instance":
@@ -192,10 +193,10 @@ class App:
 		returns:
 		DataFrame
 		"""
-		count = [1,4,3]
-		name = ['Override','getData() method','to generate tables']
-		df = pd.DataFrame({'name':name, 'count':count})
-		return df
+		try:
+			return eval("self."+str(params['output_id'])+"()")
+		except:
+			return pd.DataFrame({'name':['Override','getData() method','to generate tables'], 'count':[1,4,3]})
 
 	def getTable(self, params):
 		"""Used to create html table. Uses dataframe returned by getData by default
@@ -227,8 +228,11 @@ class App:
 		returns:
 		matplotlib.pyplot figure
 		"""
-		plt.title("Override getPlot() method to generate figures")
-		return plt.gcf()
+		try:
+			return eval("self."+str(params['output_id'])+"()")
+		except:
+			plt.title("Override getPlot() method to generate figures")
+			return plt.gcf()
 
 	def getImage(self, params):
 		"""Override this function
@@ -236,7 +240,10 @@ class App:
 		arguments: params (dict)
 		returns: matplotlib.image (figure)
 		"""
-		return np.array([[0,0,0]])
+		try:
+			return eval("self."+str(params['output_id'])+"()")
+		except:
+			return np.array([[0,0,0]])
 
 	def getHTML(self, params):
 		"""Override this function
@@ -244,7 +251,10 @@ class App:
 		arguments: params (dict)
 		returns: html (string)
 		"""
-		return "<b>Override</b> the getHTML method to insert your own HTML <i>here</i>"
+		try:
+			return eval("self."+str(params['output_id'])+"()")
+		except:
+			return "<b>Override</b> the getHTML method to insert your own HTML <i>here</i>"
 
 	def noOutput(self, params):
 		"""Override this function
@@ -254,7 +264,10 @@ class App:
 		arguments:
 		params (dict)
 		"""
-		pass
+		try:
+			return eval("self."+str(params['output_id'])+"()")
+		except:
+			pass
 
 	def getD3(self):
 		d3 = {}
@@ -279,7 +292,7 @@ class App:
 		return ""
 
 	def launch(self,host="local",port=8080):
-		webapp = Root(templateVars=self.templateVars, title=self.title, inputs=self.inputs, outputs=self.outputs, controls=self.controls, tabs=self.tabs, getJsonDataFunction=self.getJsonData, getDataFunction=self.getData, getTableFunction=self.getTable, getPlotFunction=self.getPlot, getImageFunction=self.getImage, getD3Function=self.getD3, getCustomJSFunction=self.getCustomJS, getCustomCSSFunction=self.getCustomCSS, getHTMLFunction=self.getHTML, getDownloadFunction=self.getDownload, noOutputFunction=self.noOutput)
+		webapp = self.getRoot()
 		if host!="local":
 			cherrypy.server.socket_host = '0.0.0.0'
 		cherrypy.server.socket_port = port
@@ -294,9 +307,13 @@ class App:
 		jobs.new(self.launch, kw=dict(port=port))
 		return HTML('<iframe src=http://localhost:{} width={} height={}></iframe>'.format(port,width,height))
 
+	def getRoot(self):
+		webapp = Root(templateVars=self.templateVars, title=self.title, inputs=self.inputs, outputs=self.outputs, controls=self.controls, tabs=self.tabs, getJsonDataFunction=self.getJsonData, getDataFunction=self.getData, getTableFunction=self.getTable, getPlotFunction=self.getPlot, getImageFunction=self.getImage, getD3Function=self.getD3, getCustomJSFunction=self.getCustomJS, getCustomCSSFunction=self.getCustomCSS, getHTMLFunction=self.getHTML, getDownloadFunction=self.getDownload, noOutputFunction=self.noOutput)
+		return webapp
+
 class Launch(App):
 	"""Warning: This class is depricated. Use App instead"""
-
+ 
 if __name__=='__main__':
 	app = App()
 	app.launch()
